try:
    from oauth2client import util
except ImportError:
    from oauth2client import _helpers as util
from googleapiclient.http import _retry_request, MediaDownloadProgress, HttpError, MediaIoBaseDownload


@util.positional(1)
def media_io_base_download_next_chunk(self, num_retries=0):
    if self._chunksize > 0:
        headers = {
            'range': 'bytes=%d-%d' % (
                self._progress, self._progress + self._chunksize)
        }
    else:
        headers = {}
    http = self._request.http
    resp, content = _retry_request(
        http, num_retries, 'media download', self._sleep, self._rand, self._uri,
        'GET', headers=headers)

    if resp.status in [200, 206]:
        if 'content-location' in resp and resp['content-location'] != self._uri:
            self._uri = resp['content-location']
        self._progress += len(content)
        self._fd.write(content)

        if 'content-range' in resp:
            content_range = resp['content-range']
            length = content_range.rsplit('/', 1)[1]
            self._total_size = int(length)
        elif 'content-length' in resp:
            self._total_size = int(resp['content-length'])

        if self._progress == self._total_size:
            self._done = True
        return MediaDownloadProgress(self._progress, self._total_size), self._done
    else:
        raise HttpError(resp, content, uri=self._uri)


MediaIoBaseDownload.next_chunk = media_io_base_download_next_chunk
